# API documentation

The base class for the `urn_citation` package is `Urn`, with two subclasses: `CtsUrn` for CTS URNs and `Cite2Urn` for CITE2 URNs.

::: urn_citation.Urn
    options:
      show_root_heading: true
      show_source: true
      members_order: alphabetical

## The subclasses

- [CtsUrn](ctsurn.md)
- [Cite2Urn](cite2urn.md)


